import _extends from "@babel/runtime/helpers/esm/extends";
import optimizelySDK from '@optimizely/optimizely-sdk';
import { updateIntegrations } from './integrations/handler';
var DEFAULT_OPTIONS = {
  autoUpdate: true,
  updateInterval: 5 * 60 * 1000,
  // 5 minutes
  logLevel: 'info'
};
var DEFAULT_TIMEOUT = 500;

var OptimizelyAdapter = /*#__PURE__*/function () {
  /**
   * @constructor
   * @param {object} param
   * @param {object} param.optimizely OptimizelyInstance returned by createOptimizelyInstance method
   * @param {string=} param.userId
   * @param {object} param.activeIntegrations segment activated by default
   * @param {boolean} param.hasUserConsents
   */
  function OptimizelyAdapter(_ref) {
    var optimizely = _ref.optimizely,
        userId = _ref.userId,
        _ref$activeIntegratio = _ref.activeIntegrations,
        activeIntegrations = _ref$activeIntegratio === void 0 ? {
      segment: true
    } : _ref$activeIntegratio,
        hasUserConsents = _ref.hasUserConsents;

    if (!optimizely) {
      throw new Error('optimizely instance is mandatory to use OptimizelyAdapter');
    }

    this._optimizely = optimizely;
    this._userId = userId == null ? void 0 : userId.toString();
    this._activeIntegrations = activeIntegrations;
    this.updateConsents({
      hasUserConsents: hasUserConsents
    });
  }
  /**
   * @param {object} param
   * @param {string} param.sdkKey
   * @param {object=} param.datafile
   * @param {object} param.options https://docs.developers.optimizely.com/full-stack/docs/initialize-sdk-javascript-node
   * @param {object} optimizely test purposes only, optimizely sdk
   */


  OptimizelyAdapter.createOptimizelyInstance = function createOptimizelyInstance(_ref2) {
    var _window$__INITIAL_CON;

    var optionParameter = _ref2.options,
        sdkKey = _ref2.sdkKey,
        datafile = _ref2.datafile,
        _ref2$optimizely = _ref2.optimizely,
        optimizely = _ref2$optimizely === void 0 ? optimizelySDK : _ref2$optimizely;

    var options = _extends({}, DEFAULT_OPTIONS, optionParameter);

    optimizely.setLogLevel(options.logLevel);
    optimizely.setLogger(optimizely.logging.createLogger());

    if (!datafile && typeof window !== 'undefined' && (_window$__INITIAL_CON = window.__INITIAL_CONTEXT_VALUE__) != null && _window$__INITIAL_CON.pde) {
      datafile = window.__INITIAL_CONTEXT_VALUE__.pde;
    }

    var optimizelyInstance = optimizely.createInstance({
      sdkKey: sdkKey,
      datafileOptions: options,
      datafile: datafile
    });
    return optimizelyInstance;
  }
  /**
   * @param {object} param
   * @param {object} param.attributes
   * @return {string[]}
   */
  ;

  var _proto = OptimizelyAdapter.prototype;

  _proto.getEnabledFeatures = function getEnabledFeatures(_ref3) {
    var attributes = _ref3.attributes;
    return this._optimizely.getEnabledFeatures(this._userId, attributes);
  }
  /**
   * returns the datafile, useful in a server/client scenario
   */
  ;

  _proto.getInitialData = function getInitialData() {
    var datafile = null;

    try {
      datafile = this._optimizely.getOptimizelyConfig().getDatafile();
    } catch (error) {
      // eslint-disable-next-line no-console
      console.error(error);
    }

    return datafile;
  }
  /**
   * Activates an A/B test for the specified user to start an experiment: determines whether they qualify for the experiment,
   * buckets a qualified user into a variation, and sends an impression event to Optimizely.
   * More info: https://docs.developers.optimizely.com/full-stack/docs/activate-javascript-node
   * @param {Object} params
   * @param {string} params.name
   * @param {object} [params.attributes]
   * @returns {string=} variation name
   */
  ;

  _proto.activateExperiment = function activateExperiment(_ref4) {
    var name = _ref4.name,
        attributes = _ref4.attributes;
    if (!this._hasUserConsents) return null;
    return this._optimizely.activate(name, this._userId, attributes);
  }
  /**
   * Gets the variation without tracking the impression
   * @param {Object} params
   * @param {string} params.name
   * @param {object} [params.attributes]
   * @returns {string=} variation name
   */
  ;

  _proto.getVariation = function getVariation(_ref5) {
    var name = _ref5.name,
        attributes = _ref5.attributes;
    if (!this._hasUserConsents) return null;
    return this._optimizely.getVariation(name, this._userId, attributes);
  };

  _proto.onReady = function onReady() {
    var _this = this;

    return this._optimizely.onReady({
      timeout: DEFAULT_TIMEOUT
    }).then(function () {
      return _this._optimizely;
    });
  };

  _proto.updateConsents = function updateConsents(_ref6) {
    var hasUserConsents = _ref6.hasUserConsents;
    this._hasUserConsents = hasUserConsents;
    updateIntegrations({
      hasUserConsents: this._hasUserConsents,
      activeIntegrations: this._activeIntegrations,
      optimizelyInstance: this._optimizely
    });
  };

  return OptimizelyAdapter;
}();

export { OptimizelyAdapter as default };