import { useContext } from 'react';
import PdeContext from '../contexts/PdeContext';
/**
 * Hook to use a feature toggle
 * @param {string} featureKey
 * @param {object} attributes
 * @return {{isActive: boolean}}
 */

export default function useFeature(featureKey, attributes) {
  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[useExperiment] sui-pde provider is required to work');
  var features = pde.getEnabledFeatures({
    attributes: attributes
  });
  var isActive = features.some(function (f) {
    return f === featureKey;
  });
  return {
    isActive: isActive
  };
}